@@ -2,7 +2,7 @@
  * Programmer(s): Cody J. Balos, Aaron Collier and Radu Serban @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -44,10 +44,10 @@
  * -----------------------------------------------------------------*/
 
 
-#define SUNDIALS_VERSION "7.2.1"
+#define SUNDIALS_VERSION "7.3.0"
 #define SUNDIALS_VERSION_MAJOR 7
-#define SUNDIALS_VERSION_MINOR 2
-#define SUNDIALS_VERSION_PATCH 1
+#define SUNDIALS_VERSION_MINOR 3
+#define SUNDIALS_VERSION_PATCH 0
 #define SUNDIALS_VERSION_LABEL ""
 #define SUNDIALS_GIT_VERSION ""
 
@@ -84,6 +84,11 @@
  */
 #define SUNDIALS_INDEX_TYPE int64_t
 
+/* Define the type used for 'suncountertype'.
+ * The macro will be defined with a type of the appropriate size.
+ */
+#define SUNDIALS_COUNTER_TYPE long int
+
 /* Use POSIX timers if available.
  *     #define SUNDIALS_HAVE_POSIX_TIMERS
  */
@@ -106,11 +111,11 @@
 
 /* Build metadata */
 #define SUN_C_COMPILER "Clang"
-#define SUN_C_COMPILER_VERSION "19.1.6"
+#define SUN_C_COMPILER_VERSION "20.1.1"
 #define SUN_C_COMPILER_FLAGS "-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1 -Wno-return-type -Wno-deprecated-declarations"
 
 #define SUN_CXX_COMPILER "Clang"
-#define SUN_CXX_COMPILER_VERSION "19.1.6"
+#define SUN_CXX_COMPILER_VERSION "20.1.1"
 #define SUN_CXX_COMPILER_FLAGS "-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1"
 
 #define SUN_FORTRAN_COMPILER ""
@@ -119,8 +124,8 @@
 
 #define SUN_BUILD_TYPE "Release"
 
-#define SUN_JOB_ID "20250109071236"
-#define SUN_JOB_START_TIME "20250109071236"
+#define SUN_JOB_ID "20250409091616"
+#define SUN_JOB_START_TIME "20250409091616"
 
 #define SUN_TPL_LIST "OPENMP;KLU;BLAS_LAPACK;PTHREAD"
 #define SUN_TPL_LIST_SIZE ""
